# LE_IMG class by Pavel Belyaev

Данный класс создан для простейших манипуляций с изображениями в формате jpeg, png и gif.

Для работы данного класса требуется библиотека GD

Класс делится на основные функции и вспомогательные, вспомогательные используются самим классом для работоспособности основных функций, но иногда может быть полезным использовать эти вспомогательные функции как самостоятельные для реализации специфичного функционала в вашем приложении...

## Основные функции

### Изменение размера изображения

#### Пропорциональное

Просто вписывает изображение в прямоугольник заданных размеров, если изображение меньше, то размер не меняется
```php
LE_IMG::resize($inp_path,$out_path,$max_width,$max_height);
```
* `$inp_path` и `$out_path` - путь до исходной картинки и путь куда сохранять результат
* `$max_width` и `$max_height` - размер, в который нужно вписать изображение

#### Пропорциональное с подрезкой
Данная функция красиво подрезает картинку, т.е. сперва вписывает в размер так, чтобы оно вылезало за пределы прямоугольника, но не было меньше, а дальше подрезает лишнее равномерно с каждой стороны. Если изображение после ресайза вписывается в заданную область, то ничего не вылезает и не подрезается.
```php
LE_IMG::resize_crop($inp_path,$out_path,$max_width,$max_height);
```
### Простая подрезка картинки
Иногда нужно к примеру просто срезать произвольный участок с произвольной стороны картинки
```php
LE_IMG::crop($inp_path,$out_path,$left_crop,$top_crop,$right_crop,$bottom_crop);
```

### Наложение водяных знаков (watermark)

#### Наложение на картинку текста по диагонали
```php
$conf = [
    'text'=>'mytext',
    'font'=>'/path_to_font.ttf',
    'rgb'=>'78,78,78,40' //необязательный параметр
];

LE_IMG::watermark1($path_to_img,$conf);
```



#### Наложение прозрачного png на картинку
```php
LE_IMG::watermark2($path_to_img,$stamp_path,$skeep_err=1);
```




___


## Вспомогательные функции

### Загрузка картинки
На вход передается путь до файла изображения
> Данная функция используется методами resize, resize_crop, crop, watermark1, watermark2
```php
list($width,$height,$type,$img_resource) = LE_IMG::LOAD($path);
```

Возвращаeт `array` или `false` если файла нет или у файла неподдерживаемый тип
* `$type=1` - GIF
* `$type=2` - JPEG
* `$type=3` - PNG

### Сохранение картинки
Сохраняет картинку после всех манипуляций с ресурсом LibGD
```php
LE_IMG::SAVE($img_resource,$type,$path);
```

### Вычисление новых размеров для ресайза

#### Пропорциональное уменьшение
```php
list ($new_width,$new_height) = 
LE_IMG::calc_prop($width,$height,$width_out,$height_out,$max=0);
```

calc_prop уменьшает ширину, если она больше нужной, и пропорционально высоту, далее тоже самое с высотой

* `$width`, `$height` - текущие ширина и высота картинки в пикселях
* `$width_out`, `$height_out` - размеры, в которые нужно вписать картинку, обычно ограничивающие значения по ширине и высоте, если одно из значений превышает заданное, то второе пропорционально уменьшается
* `$max` - если передать этот параметр 1 или true, то поведение функции меняется, картинку меньше нужного размера тянет на нужные размеры, да, будет мыльно, но не всегда, при наложении прозрачной картинки на картинку немного большего размера ничего не поплывет...

#### Уменьшение для подрезки
Иногда при уменьшении картинки она к примеру превращается в прямоугольник, тогда как нужно ее превратить в квадрат, т.е. уменьшить до такого прямоугольника, у которого одна из сторон будет побольше, а далее большую сторону подрезать
```php
list ($new_width,$new_height) = 
LE_IMG::calc_prop2($width,$height,$width_out,$height_out);
```

## ToDo
* Реализовать crop для картинок отличных от квадратных (тест)
* Для resize_crop устранить раздутие картинки, если входное изображение меньше, делать уменьшенную версию...
* Добавить поддержку webp


## Changelog
